@@ -717,7 +717,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def set_gelineq(
@@ -744,7 +744,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def set_atleast(
@@ -761,7 +761,7 @@ class OatClient:
         call = SetThresholdOperatorCall(fn="set_atleast", args=args)
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def set_atmost(
@@ -778,7 +778,7 @@ class OatClient:
         call = SetThresholdOperatorCall(fn="set_atmost", args=args)
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def set_equal(
@@ -795,7 +795,7 @@ class OatClient:
         call = SetThresholdOperatorCall(fn="set_equal", args=args)
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def set_and(
@@ -811,7 +811,7 @@ class OatClient:
         call = SetLogicalOperatorCall(fn="set_and", args=args)
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def set_or(
@@ -827,7 +827,7 @@ class OatClient:
         call = SetLogicalOperatorCall(fn="set_or", args=args)
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def set_not(
@@ -843,7 +843,7 @@ class OatClient:
         call = SetLogicalOperatorCall(fn="set_not", args=args)
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def set_xor(
@@ -859,7 +859,7 @@ class OatClient:
         call = SetLogicalOperatorCall(fn="set_xor", args=args)
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def set_imply(
@@ -876,7 +876,7 @@ class OatClient:
         call = SetBinaryOperatorCall(fn="set_imply", args=args)
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def set_equiv(
@@ -893,7 +893,7 @@ class OatClient:
         call = SetBinaryOperatorCall(fn="set_equiv", args=args)
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def get_id_from_alias(
@@ -908,7 +908,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def sub(
@@ -923,7 +923,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def solve(
@@ -957,7 +957,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def set_property(
@@ -974,7 +974,7 @@ class OatClient:
         )
         self._buffer.append(call),
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def set_primitives(
@@ -990,7 +990,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def get_node_ids(
@@ -1005,7 +1005,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def get_nodes(
@@ -1020,7 +1020,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def get_node(
@@ -1035,7 +1035,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def get_property_values(
@@ -1050,7 +1050,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def get_alias(
@@ -1065,7 +1065,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def get_aliases_from_id(
@@ -1080,7 +1080,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def get_ids_from_aliases(
@@ -1095,7 +1095,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
     
     def get_ids_from_dag(
@@ -1110,7 +1110,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def propagate(
@@ -1125,7 +1125,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def propagate_many(
@@ -1140,7 +1140,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def sub_many(
@@ -1155,7 +1155,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def solve_many(
@@ -1189,7 +1189,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def validate(
@@ -1204,7 +1204,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def ranks(
@@ -1219,7 +1219,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def delete_node(
@@ -1234,7 +1234,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def delete_sub(
@@ -1249,7 +1249,7 @@ class OatClient:
         )
         self._buffer.append(call)
         if execute_now:
-            return self.execute([call.out], clear_buffer=True)
+            return self.execute([call.out], clear_buffer=True)[call.out]
         return call
 
     def execute(
